@@ -6,10 +6,10 @@ use Carp qw/croak confess/;
 use Exporter::Tidy default => [qw/cmd_template/];
 use File::Spec::Functions qw/splitdir/;
 use File::Which;
-use Moo;
+use Sys::Cmd::Mo qw/is default/;
 use Sys::Cmd;
 
-our $VERSION = '0.80.2';
+our $VERSION = '0.80.3';
 our $CONFESS;
 
 sub cmd_template {
